MethodChannelFlutterElinkBle class

Inheritance

Properties

eventChannel EventChannel
final
events Stream<Map>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkHandshakeStatus(Uint8List payload, {String? remoteId}) Future<bool>
override
connect({required String remoteId, required int timeoutMs, required bool autoConnect}) Future<void>
override
decryptBroadcast(Uint8List payload) Future<Uint8List?>
override
disconnect(String remoteId) Future<void>
override
dispose() Future<void>
override
getAdapterState() Future<Map>
override
getBmVersion(String remoteId) Future<void>
通过 native SDK 增强版 0x46 指令查询 BM 版本。
override
getHandshakeEncryptData(Uint8List payload, {String? remoteId}) Future<Uint8List?>
override
getIosMtu(String remoteId) Future<Map>
通过 MethodChannel 获取 iOS 最大写入长度。 Get iOS maximum write lengths through MethodChannel.
override
initHandshake({String? remoteId}) Future<Uint8List?>
override
isSupported() Future<bool>
override
mcuDecrypt({required Uint8List mac, required Uint8List payload}) Future<Uint8List?>
override
mcuEncrypt({required Uint8List cid, required Uint8List mac, required Uint8List payload}) Future<Uint8List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBluetooth() Future<void>
请求 native 拉起系统蓝牙开启入口。
override
readRssi(String remoteId) Future<void>
override
setAndroidCommandResendCount(int resendCount) Future<void>
通过 MethodChannel 设置 Android 指令发送失败重发次数。
override
setAndroidMtu(String remoteId, int mtu) Future<bool>
override
setAndroidPreferredPhy({required String remoteId, required int txPhy, required int rxPhy}) Future<bool>
override
startScan({required int timeoutMs, required List<String> withServices, int? androidScanMode}) Future<void>
override
stopScan() Future<void>
override
toString() String
A string representation of this object.
inherited
write({required String remoteId, required Uint8List data, required String type}) Future<void>
override
writeA6({required String remoteId, required Uint8List payload}) Future<void>
override
writeA7({required String remoteId, required Uint8List payload, int? cid}) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited