FlutterElinkBlePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterElinkBlePlatform
Implementers

Constructors

FlutterElinkBlePlatform()

Properties

events Stream<Map>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkHandshakeStatus(Uint8List payload, {String? remoteId}) Future<bool>
connect({required String remoteId, required int timeoutMs, required bool autoConnect}) Future<void>
decryptBroadcast(Uint8List payload) Future<Uint8List?>
disconnect(String remoteId) Future<void>
dispose() Future<void>
getAdapterState() Future<Map>
getBmVersion(String remoteId) Future<void>
通过 native SDK 增强版 0x46 指令查询 BM 版本。
getHandshakeEncryptData(Uint8List payload, {String? remoteId}) Future<Uint8List?>
getIosMtu(String remoteId) Future<Map>
iOS only: 获取当前连接设备的最大写入长度。 iOS only: get maximum write lengths for the connected peripheral.
initHandshake({String? remoteId}) Future<Uint8List?>
isSupported() Future<bool>
mcuDecrypt({required Uint8List mac, required Uint8List payload}) Future<Uint8List?>
mcuEncrypt({required Uint8List cid, required Uint8List mac, required Uint8List payload}) Future<Uint8List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBluetooth() Future<void>
请求系统打开蓝牙,最终状态通过 adapter state 事件返回。
readRssi(String remoteId) Future<void>
setAndroidCommandResendCount(int resendCount) Future<void>
Android only: 设置指令发送失败重发次数,0 关闭,负数由 native 忽略。
setAndroidMtu(String remoteId, int mtu) Future<bool>
setAndroidPreferredPhy({required String remoteId, required int txPhy, required int rxPhy}) Future<bool>
startScan({required int timeoutMs, required List<String> withServices, int? androidScanMode}) Future<void>
stopScan() Future<void>
toString() String
A string representation of this object.
inherited
write({required String remoteId, required Uint8List data, required String type}) Future<void>
writeA6({required String remoteId, required Uint8List payload}) Future<void>
writeA7({required String remoteId, required Uint8List payload, int? cid}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterElinkBlePlatform
getter/setter pair